@@ -11,19 +11,19 @@ my %date;
 sub validate {
     my $field = shift;
 
-    return unless $field->SUPER::validate( @_ );
+    return unless $field->SUPER::validate;
 
     warn "Form::Processor::Field::FutureDate does not currently test future\n";
 
     return 1;
 
+    $field->value( $field->temp );
+
     return 1 unless $field->value_changed;
 
     return 1 if $field->value->clone->truncate( to => 'day' ) > DateTime->today;
 
-    $field->add_error('This date must be in the future');
-
-    return;
+    return $field->add_error('This date must be in the future');
 
 }
 
